#!/.env/bin/python3

import os, sys, json
from termcolor import colored, cprint
from aws_cdk import (
    aws_iam as iam,
    core
)
sys.path.append(os.path.abspath(os.curdir))
from vars import *

fileDir = os.path.dirname(os.path.realpath('__file__'))
CrossAccountPolicyFile = os.path.join(fileDir, 'iam_policies/MemberAccounts/Custodian-CrossAccount-policy.json')
with open(CrossAccountPolicyFile) as f:
  custodian_cross_account_policy = json.load(f)

PeriodicLambdaPolicyFile = os.path.join(fileDir, 'iam_policies/MemberAccounts/Custodian-periodic-lambda-policy.json')
with open(PeriodicLambdaPolicyFile) as l:
  custodian_periodic_lambda_policy = json.load(l)

class MemberAccountRoleStack(core.Stack):
  def __init__(self, app: core.App, id: str, **kwargs) -> None:
      super().__init__(app, id, **kwargs)

      crossAccountRole = iam.Role(self, "crossAccountRole", role_name='SecurityCustodian-CrossAccount-Role',
          managed_policies=None,
          assumed_by=iam.AccountPrincipal(security_account)
          ) # required


          #Loads crossAccountPolicyDocument file
      crossAccountPolicyDocument = iam.PolicyDocument.from_json(custodian_cross_account_policy)
      crossAccountPolicy = iam.Policy(self, "CustodianPolicy", document=crossAccountPolicyDocument)
      crossAccountPolicy.attach_to_role(crossAccountRole)


      periodicLambdarole = iam.Role(self, "periodicLambdarole", role_name='SecurityCustodian-periodic-lambda-role',
          managed_policies=None,
          assumed_by=iam.ServicePrincipal("lambda.amazonaws.com")) # required

      periodicLambdaDocument = iam.PolicyDocument.from_json(custodian_periodic_lambda_policy)
      periodicLambdaPolicy = iam.Policy(self, "LambdaPolicy", document=periodicLambdaDocument)
      periodicLambdaPolicy.attach_to_role(periodicLambdarole)

app = core.App()
core.Tags.of(app).add("solution", "cdk-cloudcustodian")
for account in member_accounts:
  MemberAccountRoleStack(app, 'cdk-cloudcustodian-roles-'+account, env={'account': account, 'region': var_region})
app.synth()